# eric7.Plugins.VcsPlugins.vcsMercurial.HgRevisionSelectionDialog

Module implementing a dialog to select a revision.

### Global Attributes

None

### Classes

HgRevisionSelectionDialog | Class implementing a dialog to select a revision.

### Functions

None

## HgRevisionSelectionDialog

Class implementing a dialog to select a revision.

### Derived from

QDialog, Ui_HgRevisionSelectionDialog

### Class Attributes

None

### Class Methods

None

### Methods

HgRevisionSelectionDialog | Constructor
__updateOK | Private slot to update the OK button.
getRevision | Public method to retrieve the selected revision.
on_bookmarkButton_toggled | Private slot to handle changes of the Bookmark select button.
on_bookmarkCombo_editTextChanged | Private slot to handle changes of the Bookmark combo.
on_branchButton_toggled | Private slot to handle changes of the Branch select button.
on_branchCombo_editTextChanged | Private slot to handle changes of the Branch combo.
on_idButton_toggled | Private slot to handle changes of the ID select button.
on_idEdit_textChanged | Private slot to handle changes of the ID edit.
on_tagButton_toggled | Private slot to handle changes of the Tag select button.
on_tagCombo_editTextChanged | Private slot to handle changes of the Tag combo.

### Static Methods

None

#### HgRevisionSelectionDialog (Constructor)

HgRevisionSelectionDialog(tagsList, branchesList, bookmarksList=None, noneLabel="", parent=None)

Constructor

tagsList
  list of tags (list of strings)
branchesList
  list of branches (list of strings)
bookmarksList
  list of bookmarks (list of strings)
noneLabel
  labeltext for "no revision selected" (string)
parent
  parent widget (QWidget)

#### HgRevisionSelectionDialog.__updateOK

__updateOK()

Private slot to update the OK button.

#### HgRevisionSelectionDialog.getRevision

getRevision(revset=True)

Public method to retrieve the selected revision.

revset (bool)
  flag indicating to get the revision or ID as a revset

Return:
  selected revision

Return Type:
  str

#### HgRevisionSelectionDialog.on_bookmarkButton_toggled

on_bookmarkButton_toggled(checked)

Private slot to handle changes of the Bookmark select button.

checked
  state of the button (boolean)

#### HgRevisionSelectionDialog.on_bookmarkCombo_editTextChanged

on_bookmarkCombo_editTextChanged(txt)

Private slot to handle changes of the Bookmark combo.

txt
  text of the combo (string)

#### HgRevisionSelectionDialog.on_branchButton_toggled

on_branchButton_toggled(checked)

Private slot to handle changes of the Branch select button.

checked
  state of the button (boolean)

#### HgRevisionSelectionDialog.on_branchCombo_editTextChanged

on_branchCombo_editTextChanged(txt)

Private slot to handle changes of the Branch combo.

txt
  text of the combo (string)

#### HgRevisionSelectionDialog.on_idButton_toggled

on_idButton_toggled(checked)

Private slot to handle changes of the ID select button.

checked
  state of the button (boolean)

#### HgRevisionSelectionDialog.on_idEdit_textChanged

on_idEdit_textChanged(txt)

Private slot to handle changes of the ID edit.

txt
  text of the edit (string)

#### HgRevisionSelectionDialog.on_tagButton_toggled

on_tagButton_toggled(checked)

Private slot to handle changes of the Tag select button.

checked
  state of the button (boolean)

#### HgRevisionSelectionDialog.on_tagCombo_editTextChanged

on_tagCombo_editTextChanged(txt)

Private slot to handle changes of the Tag combo.

txt
  text of the combo (string)

Up